//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[ShantenWithGot](index.md)/[ankanToAdvance](ankan-to-advance.md)

# ankanToAdvance

[common]\

@EncodeDefault

val [ankanToAdvance](ankan-to-advance.md): [Map](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-map/index.html)&lt;[Tile](../../mahjongutils.models/-tile/index.md), [ShantenWithoutGot](../-shanten-without-got/index.md)&gt;

每种暗杠后的向听信息
